lilypondfiletools.AttributedBlock
=================================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.format

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.is_formatted_when_empty

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__repr__

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__str__

    Inherited from `__builtin__.object`
